@@ -16,7 +16,7 @@ from typing import IO, Any, Dict, List, Type, Union
 
 from botocore.client import ClientMeta
 
-from mypy_boto3_lex_runtime.type_defs import (
+from .type_defs import (
     ActiveContextTypeDef,
     DeleteSessionResponseTypeDef,
     DialogActionTypeDef,
@@ -55,7 +55,7 @@ class Exceptions:
 
 class LexRuntimeServiceClient:
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.70/reference/services/lex-runtime.html#LexRuntimeService.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.93/reference/services/lex-runtime.html#LexRuntimeService.Client)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_lex_runtime/client.html)
     """
 
@@ -64,16 +64,16 @@ class LexRuntimeServiceClient:
 
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.70/reference/services/lex-runtime.html#LexRuntimeService.Client.can_paginate)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_lex_runtime/client.html#can-paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.93/reference/services/lex-runtime.html#LexRuntimeService.Client.can_paginate)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_lex_runtime/client.html#can_paginate)
         """
 
     def delete_session(
-        self, botName: str, botAlias: str, userId: str
+        self, *, botName: str, botAlias: str, userId: str
     ) -> DeleteSessionResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.70/reference/services/lex-runtime.html#LexRuntimeService.Client.delete_session)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_lex_runtime/client.html#delete-session)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.93/reference/services/lex-runtime.html#LexRuntimeService.Client.delete_session)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_lex_runtime/client.html#delete_session)
         """
 
     def generate_presigned_url(
@@ -84,20 +84,21 @@ class LexRuntimeServiceClient:
         HttpMethod: str = None,
     ) -> str:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.70/reference/services/lex-runtime.html#LexRuntimeService.Client.generate_presigned_url)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_lex_runtime/client.html#generate-presigned-url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.93/reference/services/lex-runtime.html#LexRuntimeService.Client.generate_presigned_url)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_lex_runtime/client.html#generate_presigned_url)
         """
 
     def get_session(
-        self, botName: str, botAlias: str, userId: str, checkpointLabelFilter: str = None
+        self, *, botName: str, botAlias: str, userId: str, checkpointLabelFilter: str = None
     ) -> GetSessionResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.70/reference/services/lex-runtime.html#LexRuntimeService.Client.get_session)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_lex_runtime/client.html#get-session)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.93/reference/services/lex-runtime.html#LexRuntimeService.Client.get_session)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_lex_runtime/client.html#get_session)
         """
 
     def post_content(
         self,
+        *,
         botName: str,
         botAlias: str,
         userId: str,
@@ -106,30 +107,32 @@ class LexRuntimeServiceClient:
         sessionAttributes: str = None,
         requestAttributes: str = None,
         accept: str = None,
-        activeContexts: str = None,
+        activeContexts: str = None
     ) -> PostContentResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.70/reference/services/lex-runtime.html#LexRuntimeService.Client.post_content)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_lex_runtime/client.html#post-content)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.93/reference/services/lex-runtime.html#LexRuntimeService.Client.post_content)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_lex_runtime/client.html#post_content)
         """
 
     def post_text(
         self,
+        *,
         botName: str,
         botAlias: str,
         userId: str,
         inputText: str,
         sessionAttributes: Dict[str, str] = None,
         requestAttributes: Dict[str, str] = None,
-        activeContexts: List["ActiveContextTypeDef"] = None,
+        activeContexts: List["ActiveContextTypeDef"] = None
     ) -> PostTextResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.70/reference/services/lex-runtime.html#LexRuntimeService.Client.post_text)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_lex_runtime/client.html#post-text)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.93/reference/services/lex-runtime.html#LexRuntimeService.Client.post_text)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_lex_runtime/client.html#post_text)
         """
 
     def put_session(
         self,
+        *,
         botName: str,
         botAlias: str,
         userId: str,
@@ -137,9 +140,9 @@ class LexRuntimeServiceClient:
         dialogAction: "DialogActionTypeDef" = None,
         recentIntentSummaryView: List["IntentSummaryTypeDef"] = None,
         accept: str = None,
-        activeContexts: List["ActiveContextTypeDef"] = None,
+        activeContexts: List["ActiveContextTypeDef"] = None
     ) -> PutSessionResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.70/reference/services/lex-runtime.html#LexRuntimeService.Client.put_session)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_lex_runtime/client.html#put-session)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.93/reference/services/lex-runtime.html#LexRuntimeService.Client.put_session)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_lex_runtime/client.html#put_session)
         """
